{
  "type": "record",
  "name": "TagProperties",
  "namespace": "com.linkedin.pegasus2avro.tag",
  "doc": "Properties associated with a Tag",
  "fields": [
    {
      "name": "name",
      "type": "string",
      "doc": "Display name of the tag",
      "Searchable": {
        "boostScore": 10.0,
        "enableAutocomplete": true,
        "fieldType": "TEXT_PARTIAL"
      }
    },
    {
      "name": "description",
      "type": [
        "null",
        "string"
      ],
      "doc": "Documentation of the tag",
      "default": null,
      "Searchable": {}
    },
    {
      "name": "colorHex",
      "type": [
        "null",
        "string"
      ],
      "doc": "The color associated with the Tag in Hex. For example #FFFFFF.",
      "default": null
    }
  ],
  "Aspect": {
    "name": "tagProperties"
  }
}