{
  "type": "record",
  "name": "MLFeatureTableProperties",
  "namespace": "com.linkedin.pegasus2avro.ml.metadata",
  "doc": "Properties associated with a MLFeatureTable",
  "fields": [
    {
      "name": "customProperties",
      "type": {
        "type": "map",
        "values": "string"
      },
      "doc": "Custom property bag.",
      "default": {},
      "Searchable": {
        "/*": {
          "queryByDefault": true
        }
      }
    },
    {
      "name": "description",
      "type": [
        "null",
        "string"
      ],
      "doc": "Documentation of the MLFeatureTable",
      "default": null
    },
    {
      "name": "mlFeatures",
      "type": [
        "null",
        {
          "type": "array",
          "items": "string"
        }
      ],
      "doc": "List of features contained in the feature table",
      "default": null,
      "Relationship": {
        "/*": {
          "entityTypes": [
            "mlFeature"
          ],
          "name": "Contains"
        }
      },
      "Searchable": {
        "/*": {
          "fieldName": "features",
          "fieldType": "URN"
        }
      }
    },
    {
      "name": "mlPrimaryKeys",
      "type": [
        "null",
        {
          "type": "array",
          "items": "string"
        }
      ],
      "doc": "List of primary keys in the feature table (if multiple, assumed to act as a composite key)",
      "default": null,
      "Relationship": {
        "/*": {
          "entityTypes": [
            "mlPrimaryKey"
          ],
          "name": "KeyedBy"
        }
      },
      "Searchable": {
        "/*": {
          "fieldName": "primaryKeys",
          "fieldType": "URN"
        }
      }
    }
  ],
  "Aspect": {
    "name": "mlFeatureTableProperties"
  }
}