{
  "type": "record",
  "name": "IntendedUse",
  "namespace": "com.linkedin.pegasus2avro.ml.metadata",
  "doc": "Intended Use for the ML Model",
  "fields": [
    {
      "name": "primaryUses",
      "type": [
        "null",
        {
          "type": "array",
          "items": "string"
        }
      ],
      "doc": "Primary Use cases for the MLModel.",
      "default": null
    },
    {
      "name": "primaryUsers",
      "type": [
        "null",
        {
          "type": "array",
          "items": {
            "type": "enum",
            "name": "IntendedUserType",
            "symbols": [
              "ENTERPRISE",
              "HOBBY",
              "ENTERTAINMENT"
            ]
          }
        }
      ],
      "doc": "Primary Intended Users - For example, was the MLModel developed for entertainment purposes, for hobbyists, or enterprise solutions?",
      "default": null
    },
    {
      "name": "outOfScopeUses",
      "type": [
        "null",
        {
          "type": "array",
          "items": "string"
        }
      ],
      "doc": "Highlight technology that the MLModel might easily be confused with, or related contexts that users could try to apply the MLModel to.",
      "default": null
    }
  ],
  "Aspect": {
    "name": "intendedUse"
  }
}