{
  "type": "record",
  "name": "MLModelDeploymentKey",
  "namespace": "com.linkedin.pegasus2avro.metadata.key",
  "doc": "Key for an ML model deployment",
  "fields": [
    {
      "name": "platform",
      "type": "string",
      "doc": "Standardized platform urn for the model Deployment",
      "java": {
        "class": "com.linkedin.pegasus2avro.common.urn.Urn"
      }
    },
    {
      "name": "name",
      "type": "string",
      "doc": "Name of the MLModelDeployment",
      "Searchable": {
        "boostScore": 10.0,
        "enableAutocomplete": true,
        "fieldType": "TEXT_PARTIAL"
      }
    },
    {
      "name": "origin",
      "type": {
        "type": "enum",
        "name": "FabricType",
        "namespace": "com.linkedin.pegasus2avro.common",
        "doc": "Fabric group type",
        "symbols": [
          "DEV",
          "TEST",
          "QA",
          "UAT",
          "EI",
          "PRE",
          "STG",
          "NON_PROD",
          "PROD",
          "CORP"
        ],
        "symbolDocs": {
          "CORP": "Designates corporation fabrics",
          "DEV": "Designates development fabrics",
          "EI": "Designates early-integration fabrics",
          "NON_PROD": "Designates non-production fabrics",
          "PRE": "Designates pre-production fabrics",
          "PROD": "Designates production fabrics",
          "QA": "Designates quality assurance fabrics",
          "STG": "Designates staging fabrics",
          "TEST": "Designates testing fabrics",
          "UAT": "Designates user acceptance testing fabrics"
        }
      },
      "doc": "Fabric type where model Deployment belongs to or where it was generated",
      "Searchable": {
        "addToFilters": true,
        "fieldType": "TEXT_PARTIAL",
        "filterNameOverride": "Environment",
        "queryByDefault": false
      }
    }
  ],
  "Aspect": {
    "name": "mlModelDeploymentKey"
  }
}