{
  "type": "record",
  "name": "GlossaryTerms",
  "namespace": "com.linkedin.pegasus2avro.common",
  "doc": "Related business terms information",
  "fields": [
    {
      "name": "terms",
      "type": {
        "type": "array",
        "items": {
          "type": "record",
          "name": "GlossaryTermAssociation",
          "doc": "Properties of an applied glossary term.",
          "fields": [
            {
              "name": "urn",
              "type": "string",
              "doc": "Urn of the applied glossary term",
              "Relationship": {
                "entityTypes": [
                  "glossaryTerm"
                ],
                "name": "TermedWith"
              },
              "Searchable": {
                "addToFilters": true,
                "fieldName": "glossaryTerms",
                "fieldType": "URN",
                "filterNameOverride": "Glossary Term",
                "hasValuesFieldName": "hasGlossaryTerms"
              },
              "java": {
                "class": "com.linkedin.pegasus2avro.common.urn.GlossaryTermUrn"
              }
            }
          ]
        }
      },
      "doc": "The related business terms"
    },
    {
      "name": "auditStamp",
      "type": {
        "type": "record",
        "name": "AuditStamp",
        "doc": "Data captured on a resource/association/sub-resource level giving insight into when that resource/association/sub-resource moved into a particular lifecycle stage, and who acted to move it into that specific lifecycle stage.",
        "fields": [
          {
            "name": "time",
            "type": "long",
            "doc": "When did the resource/association/sub-resource move into the specific lifecycle stage represented by this AuditEvent."
          },
          {
            "name": "actor",
            "type": "string",
            "doc": "The entity (e.g. a member URN) which will be credited for moving the resource/association/sub-resource into the specific lifecycle stage. It is also the one used to authorize the change.",
            "java": {
              "class": "com.linkedin.pegasus2avro.common.urn.Urn"
            }
          },
          {
            "name": "impersonator",
            "type": [
              "null",
              "string"
            ],
            "doc": "The entity (e.g. a service URN) which performs the change on behalf of the Actor and must be authorized to act as the Actor.",
            "default": null,
            "java": {
              "class": "com.linkedin.pegasus2avro.common.urn.Urn"
            }
          }
        ]
      },
      "doc": "Audit stamp containing who reported the related business term"
    }
  ],
  "Aspect": {
    "name": "glossaryTerms"
  }
}